Command line options — Firebird Pack for PowerConsole v0.9.1 documentation

### Navigation

- index
- next |
- previous |
- Firebird Pack for PowerConsole v0.9.1 documentation »

# Command line options

Firebird Pack adds next command line options to PowerConsole:

`--type-conv```
  KInterbasDB type conversion code that PowerConsole should use. In short, if you’re using Firebird 2.1, you may want to use code 300 to get automatic character set transaltion for BLOB fields (unluding metadata BLOBs like PSQL source code). See KInterbasDB documentation about dynamic type translation fo details.

### Navigation

- index
- next |
- previous |
- Firebird Pack for PowerConsole v0.9.1 documentation »